synapse
=======

Synapse is a "batteries included" intelligence analysis platform designed to help analysts and algorithms answer complex questions which require the fusion of data across different disciplines.

|codecov|_ |circleci|_ |dockerhub|_ |rtd|_

Installation
------------
Synapse is available as a Python Package on pypi_ and as a Docker image on dockerhub_.

Documentation
-------------

API Documentation and User Guides can be found at https://synapse.docs.vertex.link

Chat
----

Join the Vertex Project on |slack|_!

.. |circleci| image:: https://circleci.com/gh/vertexproject/synapse/tree/master.svg?style=svg
..  _circleci: https://circleci.com/gh/vertexproject/synapse/tree/master

.. |codecov| image:: https://codecov.io/gh/vertexproject/synapse/branch/master/graph/badge.svg?branch=master
.. _codecov: https://codecov.io/gh/vertexproject/synapse

.. |rtd| image:: https://readthedocs.com/projects/vertex-synapse/badge/?version=latest
.. _rtd: https://synapse.docs.vertex.link/en/latest/?badge=latest

.. |dockerhub| image:: https://img.shields.io/docker/build/vertexproject/synapse.svg?branch=master
.. _dockerhub: https://hub.docker.com/r/vertexproject/synapse/

.. |slack| image:: http://slackinvite.vertex.link/badge.svg
.. _slack: http://slackinvite.vertex.link/

.. _pypi: https://pypi.python.org/pypi/synapse
